@@ -10,22 +10,23 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.03';
-$DATE = '2003/09/15';
+$VERSION = '0.04';
+$DATE = '2003/09/19';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Text_Column.pm' => [qw(0.03 2003/09/15), 'revised 0.02'],
-    'MANIFEST' => [qw(0.03 2003/09/15), 'generated, replaces 0.02'],
-    'Makefile.PL' => [qw(0.03 2003/09/15), 'generated, replaces 0.02'],
-    'README' => [qw(0.03 2003/09/15), 'generated, replaces 0.02'],
-    'lib/Text/Column.pm' => [qw(1.09 2003/07/05), 'unchanged'],
+    'lib/Docs/Site_SVD/Text_Column.pm' => [qw(0.04 2003/09/19), 'revised 0.03'],
+    'MANIFEST' => [qw(0.04 2003/09/19), 'generated, replaces 0.03'],
+    'Makefile.PL' => [qw(0.04 2003/09/19), 'generated, replaces 0.03'],
+    'README' => [qw(0.04 2003/09/19), 'generated, replaces 0.03'],
+    'lib/Text/Column.pm' => [qw(1.1 2003/09/19), 'revised 1.09'],
     't/Text/Column.d' => [qw(0.01 2003/07/27), 'unchanged'],
     't/Text/Column.pm' => [qw(0.01 2003/07/05), 'unchanged'],
-    't/Text/Column.t' => [qw(0.05 2003/09/15), 'revised 0.04'],
-    'tlib/File/Package.pm' => [qw(1.12 2003/09/15), 'revised 1.1'],
-    'tlib/Test/Tech.pm' => [qw(1.13 2003/09/15), 'revised 1.11'],
+    't/Text/Column.t' => [qw(0.05 2003/09/15), 'unchanged'],
+    'tlib/File/Package.pm' => [qw(1.12 2003/09/19), 'unchanged'],
+    'tlib/Test/Tech.pm' => [qw(1.14 2003/09/19), 'revised 1.13'],
+    'tlib/Data/Secs2.pm' => [qw(1.14 2003/09/19), 'new'],
 
 );
 
@@ -52,11 +53,11 @@ use vars qw(%INVENTORY);
 
  Text::Column - Format tables from hashes and arrays suitable for PODs
 
- Revision: B
+ Revision: C
 
- Version: 0.03
+ Version: 0.04
 
- Date: 2003/09/15
+ Date: 2003/09/19
 
  Prepared for: General Public 
 
@@ -102,7 +103,7 @@ by formatting raw array and hash data into tables for inclusion in PODS
 
 =head2 1.3 Document overview.
 
-This document releases Text::Column version 0.03
+This document releases Text::Column version 0.04
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -118,8 +119,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/Text-Column-0.03
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.03
+   http://www.softwarediamonds/packages/Text-Column-0.04
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.04
 
 
 Restrictions regarding duplication and license provisions
@@ -187,16 +188,17 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Text_Column.pm                             0.03    2003/09/15 revised 0.02
- MANIFEST                                                     0.03    2003/09/15 generated, replaces 0.02
- Makefile.PL                                                  0.03    2003/09/15 generated, replaces 0.02
- README                                                       0.03    2003/09/15 generated, replaces 0.02
- lib/Text/Column.pm                                           1.09    2003/07/05 unchanged
+ lib/Docs/Site_SVD/Text_Column.pm                             0.04    2003/09/19 revised 0.03
+ MANIFEST                                                     0.04    2003/09/19 generated, replaces 0.03
+ Makefile.PL                                                  0.04    2003/09/19 generated, replaces 0.03
+ README                                                       0.04    2003/09/19 generated, replaces 0.03
+ lib/Text/Column.pm                                           1.1     2003/09/19 revised 1.09
  t/Text/Column.d                                              0.01    2003/07/27 unchanged
  t/Text/Column.pm                                             0.01    2003/07/05 unchanged
- t/Text/Column.t                                              0.05    2003/09/15 revised 0.04
- tlib/File/Package.pm                                         1.12    2003/09/15 revised 1.1
- tlib/Test/Tech.pm                                            1.13    2003/09/15 revised 1.11
+ t/Text/Column.t                                              0.05    2003/09/15 unchanged
+ tlib/File/Package.pm                                         1.12    2003/09/19 unchanged
+ tlib/Test/Tech.pm                                            1.14    2003/09/19 revised 1.13
+ tlib/Data/Secs2.pm                                           1.14    2003/09/19 new
 
 
 =head2 3.3 Changes
@@ -258,6 +260,11 @@ with Archive::TarGzip 0.02 that uses mode 777 for directories instead of 666. St
 emails from Unix installers about untar not being able to change to
 a directory with mode of 666.
 
+=item Text-Column-0.04
+
+Add the module 'Data::Secs2' in the tlib that provides 'stringify' support
+for the 'Test::Tech' module.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -291,8 +298,8 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/Text-Column-0.03
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.03
+   http://www.softwarediamonds/packages/Text-Column-0.04
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.04
 
 
 =item Prerequistes.
@@ -408,11 +415,11 @@ __DATA__
 DISTNAME: Text-Column^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.03^
+VERSION : 0.04^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.02^
-REVISION: B^
+PREVIOUS_RELEASE: 0.03^
+REVISION: C^
 
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
@@ -441,6 +448,7 @@ lib/Text/Column.pm
 t/Text/Column.*
 lib/File/Package.pm => tlib/File/Package.pm
 lib/Test/Tech.pm => tlib/Test/Tech.pm
+lib/Data/Secs2.pm => tlib/Data/Secs2.pm
 ^
 
 PREREQ_PM:  ^
@@ -505,6 +513,11 @@ with Archive::TarGzip 0.02 that uses mode 777 for directories instead of 666. St
 emails from Unix installers about untar not being able to change to
 a directory with mode of 666.
 
+\=item Text-Column-0.04
+
+Add the module 'Data::Secs2' in the tlib that provides 'stringify' support
+for the 'Test::Tech' module.
+
 \=back
 
 ^
